@@ -1,13 +1,13 @@
 <?php
 /*
-  @version   v5.20.9  21-Dec-2016
+  @version   v5.20.14  06-Jan-2019
   @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
   @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
   Released under both BSD license and Lesser GPL library license.
   Whenever there is any discrepancy between the two licenses,
   the BSD license will take precedence. See License.txt.
   Set tabs to 4 for best viewing.
-  Latest version is available at http://adodb.sourceforge.net
+  Latest version is available at http://adodb.org/
 */
 // Code contributed by "stefan bogdan" <sbogdan#rsb.ro>
 
@@ -609,9 +609,8 @@ class ADODB_odbtp extends ADOConnection{
 
 	function _query($sql,$inputarr=false)
 	{
-	global $php_errormsg;
-
-        $this->_errorMsg = false;
+		$last_php_error = $this->resetLastError();
+		$this->_errorMsg = false;
 		$this->_errorCode = false;
 
  		if ($inputarr) {
@@ -620,7 +619,7 @@ class ADODB_odbtp extends ADOConnection{
 			} else {
 				$stmtid = @odbtp_prepare($sql,$this->_connectionID);
 				if ($stmtid == false) {
-					$this->_errorMsg = $php_errormsg;
+					$this->_errorMsg = $this->getChangedErrorMsg($last_php_error);
 					return false;
 				}
 			}
